@@ -6,6 +6,15 @@ from enum import StrEnum
 class Position(StrEnum):
     """An enumeration over the different positions."""
 
+    GOALKEEPER = "G"
+    CENTRE_DEFENDER_LEFT = "CD-L"
+    CENTRE_DEFENDER_RIGHT = "CD-R"
+    LEFT_BACK = "LB"
+    RIGHT_BACK = "RB"
+    ATTACKING_MIDFIELDER = "AM"
+    CENTRAL_MIDFIELDER = "CM"
+    LEFT_MIDFIELDER = "LM"
+
 
 _POSITIONS = {str(x): x for x in Position}
 
