@@ -18,8 +18,8 @@ def create_espn_venue_model(
     version: str,
 ) -> VenueModel:
     """Create a venue model from an ESPN result."""
-    identifier = venue["id"]
     name = venue.get("fullName", venue.get("name"))
+    identifier = venue.get("id", name)
     venue_address = venue.get("address")
     address = None
     if venue_address is not None:
@@ -33,7 +33,7 @@ def create_espn_venue_model(
         )
     else:
         address = create_google_address_model(
-            name + " College",
+            name,
             session,
             dt,
         )
