@@ -8,10 +8,6 @@ from ..aussportsbetting.nfl_aussportsbetting_league_model import \
     NFLAusSportsBettingLeagueModel
 from ..espn.nfl_espn_league_model import NFLESPNLeagueModel
 from ..oddsportal.nfl_oddsportal_league_model import NFLOddsPortalLeagueModel
-from ..sportsdb.nfl_sportsdb_league_model import NFLSportsDBLeagueModel
-
-# from ..sportsreference.nfl_sportsreference_league_model import \
-#    NFLSportsReferenceLeagueModel
 
 LOS_ANGELES_RAMS = "135907"
 CHICAGO_BEARS = "134938"
@@ -390,9 +386,9 @@ class NFLCombinedLeagueModel(CombinedLeagueModel):
             League.NFL,
             [
                 NFLESPNLeagueModel(session, position=0),
-                NFLSportsDBLeagueModel(session, position=1),
-                NFLAusSportsBettingLeagueModel(session, position=2),
-                NFLOddsPortalLeagueModel(session, position=3),
+                NFLAusSportsBettingLeagueModel(session, position=1),
+                NFLOddsPortalLeagueModel(session, position=2),
+                # NFLSportsDBLeagueModel(session, position=3),
                 # NFLSportsReferenceLeagueModel(session, position=4),
             ],
             league_filter,
