@@ -10,6 +10,7 @@ from scrapesession.scrapesession import ScrapeSession  # type: ignore
 from scrapesession.scrapesession import create_scrape_session
 
 from .data.afl import AFLLeagueModel
+from .data.atp import ATPLeagueModel
 from .data.epl import EPLLeagueModel
 from .data.fifa import FIFALeagueModel
 from .data.hkjc import HKJCLeagueModel
@@ -70,6 +71,8 @@ class SportsBall:
                 self._leagues[league] = IPLLeagueModel(self._session, league_filter)
             elif league == League.FIFA:
                 self._leagues[league] = FIFALeagueModel(self._session, league_filter)
+            elif league == League.ATP:
+                self._leagues[league] = ATPLeagueModel(self._session, league_filter)
             else:
                 raise ValueError(f"Unrecognised league: {league}")
         return self._leagues[league]
